# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs


class FolderResponse(UniversalBaseModel):
    """
    Combined response with tree data and visualization.
    """

    structure_tree_ascii: str
    tree_data: typing.Dict[str, "AssetNode"]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .asset_node import AssetNode  # noqa: E402, F401, I001

update_forward_refs(FolderResponse)
